@@ -25,7 +25,7 @@
       cat(indexTmp, sep="\n", file=new.index, append=FALSE)
       
       # and replace it
-      file.copy(from=old.index,to=paste(tools:::file_path_sans_ext(old.index),"_DEFAULT.html", sep=""))
+      file.copy(from=old.index,to=paste(tools::file_path_sans_ext(old.index),"_DEFAULT.html", sep=""))
       file.copy(from=new.index,to=old.index,overwrite=TRUE)
     }
     
@@ -64,6 +64,6 @@
       packageStartupMessage("Customed index built!")
     }
     
-    packageStartupMessage(paste(pkgname, RFver, "loaded."))
+    packageStartupMessage(paste(pkgname, RFver, "loaded.\n\nType browseVignettes(package='biomod2') to access directly biomod2 vignettes."))
   }
 }
\ No newline at end of file
